import 'package:flutter/cupertino.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/ui/component/nui_shadow_view.dart';

class NUIPersistentHeader extends SliverPersistentHeaderDelegate{
  NUIPersistentHeader({@required this.child, this.background: NUIColors.NUITransparent, @required this.height, this.shadow});
  Widget child;
  double height;
  Color background;
  NUIShadowLinearView shadow;

  @override
  Widget build(BuildContext context, double shrinkOffset, bool overlapsContent) {
    if(shadow != null) {
      return Stack(
          children: [
            Container(
              child: child,
              color: background ?? NUIColors.NUITransparent,
            ),
            Visibility(
                visible: shrinkOffset > 0.0,
                child: shadow
            )
          ]
      );
    }
    else{
      return Container(
        child: child,
        color: background ?? NUIColors.NUITransparent,
      );
    }
  }

  @override
  double get maxExtent => height;

  @override
  double get minExtent => height;

  @override
  bool shouldRebuild(covariant SliverPersistentHeaderDelegate oldDelegate) {
    return shadow != null;
  }
}

class NUIHeaderTabView extends StatefulWidget {
  NUIHeaderTabView({this.header, this.persistentHeader, @required this.body});
  final Widget header;
  final NUIPersistentHeader persistentHeader;
  final Widget body;
  @override
  _NUIHeaderTabViewState createState() => _NUIHeaderTabViewState();
}

class _NUIHeaderTabViewState extends State<NUIHeaderTabView> {
  @override
  Widget build(BuildContext context) {
    return NestedScrollView(
        headerSliverBuilder: (BuildContext context, bool innerBoxIsScrolled) {
          List<Widget> children = List();
          if(widget.header != null) {
            children.add(
              SliverToBoxAdapter(
                child: widget.header,
              )
            );
          }
          if(widget.persistentHeader != null) {
            children.add(
              SliverPersistentHeader(
                  pinned: true,
                  delegate: widget.persistentHeader
              ),
            );
          }

          return children;
        },
        body: widget.body
    );
  }
}
